%% utee-thesis.cls
%% Copyright 2014 Morten Piibeleht
%
% A latex class for natural science BSc and MSc theses at at the University of
% Tartu. It adheres to the typesetting requirements set by the Faculty of
% Science and Technology (LOTE), available here:
%   http://www.lote.ut.ee/et/oppetoo/loodus-tehnoloogiateaduskonna-loputoodele-esitatavad-nouded-kaitsmise-kord
%
% In addition to the typesetting requirements it also provides tools to easily
% create the standard compulsory parts of the thesis (e.g. english abstract,
% license).
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.

% The class is based on the LaTeX report class. The 12pt font, A4 paper and 1.5
% spacing are the official requirements by LOTE.

\LoadClass[a4paper,12pt]{report} % Paberi ja teksti suuruse määramine.
\RequirePackage{setspace} % Vajalik reavahe suuruse määramiseks.
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc} % Need kaks paketti tagavad muu hulgas selle, et ä on tõesti ä ja mitte täppidega a. Silmaga vaadates pole võimalik neid eristada, kuid copy-paste on teisel juhul tülikas.
\RequirePackage{mathptmx} % Fondi valik.
\RequirePackage[english,estonian]{babel} % Erinevad nimetused jms.
\RequirePackage{iflang} % Sellel paketil põhineb käesoleva klassifaili kakskeelsus.
\RequirePackage[hidelinks]{hyperref} % Tagab, et tekstisisesed viited on ühtlasi lingid, mis suunavad viidatavasse kohta. hidelinks tagab, et need lingid pole kuidagi eriliselt tähistatud, nagu need selle puudumisel oleks.
\RequirePackage{parskip} % See pakett eemaldab tekstist taandread.
\RequirePackage{natbib} % Viidete jaoks.
\RequirePackage{graphicx} % Piltide ja jooniste jaoks.
\RequirePackage{amsmath} % Valemite jaoks.
\RequirePackage[nottoc]{tocbibind} % Lisab kirjanduse loetelu sisukorda.
\RequirePackage[none]{hyphenat} % Sõnade poolitamise vältimine.

\sloppy % Kohendab sõnadevahelisi tühikuid.
\onehalfspacing % Reavahe suuruse määramine.
% Valemite poolitamise vältimine.
\relpenalty=10000 
\binoppenalty=10000
% Teksti paigutuse paikapanemine.
\topmargin=-0.75cm
\textheight=23.5cm
\textwidth=16cm
\oddsidemargin=-0.05cm 

\newif\iftwosupervisors
\newif\ifmastersthesis

%%%%%%%%%%%%          MAIN  CODE          %%%%%%%%%%%%

%%%%%%    Parameters

% Vajalike muutujate defineerimine.
\newcommand*{\institute}[1]%
  {\ifx\empty#1\empty\else\gdef\@institute{#1}\fi}
\renewcommand*{\author}[1]%
  {\ifx\empty#1\empty\else\gdef\@author{#1}\fi}
\newcommand*{\firstsupervisor}[1]%
  {\ifx\empty#1\empty\else\gdef\@firstsupervisor{#1}\fi}
\newcommand*{\secondsupervisor}[1]%
  {\ifx\empty#1\empty\else\gdef\@secondsupervisor{#1}\fi}
\renewcommand*{\title}[1]%
  {\ifx\empty#1\empty\else\gdef\@title{#1}\fi}

% Vaikimisi väärtused muutujate jaoks.
\institute{\emph{Mis instituudis sa lõputööd teed?}}
\author{\emph{Mis su nimi on?}}
\firstsupervisor{\emph{Kes on sinu juhendaja?}}
\secondsupervisor{\emph{Kes on sinu teine juhendaja?}}
\title{\emph{Mis on sinu töö pealkiri?}}

% Tiitellehe vormistamine.
\renewcommand*{\maketitle}{
	\begin{titlepage}
	\large\singlespacing
	\begin{center}
    \IfLanguageName{english}{UNIVERSITY OF TARTU}{TARTU ÜLIKOOL}\\[3mm]
	\IfLanguageName{english}{Faculty of Science and Technology}{Loodus- ja tehnoloogiateaduskond}\\[3mm]
		{\@institute}
		\vfill\vfill\vfill

		\large
		{\@author}\\[5mm]
		\Large
		\textbf{\textsc{\@title}}\\[7mm]

		\large
		\ifmastersthesis
		    \IfLanguageName{english}{Master's thesis (30 ECTS)}{Magistritöö (30 EAP)}
		\else
		    \IfLanguageName{english}{Bachelor's thesis (12 ECTS)}{Bakalaureusetöö (12 EAP)}
		\fi 
		\vfill%\vfill
		\begin{flushright}
		    \iftwosupervisors
			    \IfLanguageName{english}{Supervisors}{Juhendajad}:\\
			    {\@firstsupervisor}\\
			    {\@secondsupervisor}
			\else
			    \IfLanguageName{english}{Supervisor}{Juhendaja}:\\
			    {\@firstsupervisor}
			\fi
		\end{flushright}
		\vfill\vfill\vfill
		Tartu ~ \the\year
	\end{center}
	\setcounter{page}{1}
	\end{titlepage}
	\setcounter{page}{2}
}

% See käsklus tekitab ilma järjenumbrita peatüki, mis on vajalik sissejuhatuse ning tänuavalduste vormistamiseks.
\newcommand*{\chapterNoNumber}[1]
	{\chapter*{#1}\addcontentsline{toc}{chapter}{#1}}

% Koostab automaatselt töö põhikeelse kokkuvõtte pealkirja.
\newcommand*{\makeMainSummaryTitle}[0]{
    \begin{center}
    {\fontsize{20}{24}\bf {\@title}}\\
    {\fontsize{18}{22}\bf {\@author}}
    \end{center}
    \vspace{-60pt}
    \chapter*{\centering \IfLanguageName{english}{Summary}{Kokkuvõte}}
    \addcontentsline{toc}{chapter}{\IfLanguageName{english}{Summary}{Kokkuvõte}}
    \vspace{-30pt}
}

% Koostab töö tõlgitud kokkuvõtte pealkirja.
\newcommand*{\makeTranslatedSummaryTitle}[1]{
    \begin{center}
    {\fontsize{20}{24}\bf #1}\\
    {\fontsize{18}{22}\bf {\@author}}
    \end{center}
    \vspace{-60pt}
    \chapter*{\centering \IfLanguageName{english}{Summary}{Kokkuvõte}}
    \addcontentsline{toc}{chapter}{\IfLanguageName{english}{Summary}{Kokkuvõte}}
    \vspace{-30pt}
}

% Tekitab automaatselt kohustusliku litsentsilehekülje.
\newcommand*{\makelicence}[0]{
    \begin{otherlanguage}{estonian}
        \chapter*{Lihtlitsents lõputöö reprodutseerimiseks ja lõputöö üldsusele kättesaadavaks tegemiseks}
        \addcontentsline{toc}{chapter}{Lihtlitsents}
        \thispagestyle{empty}
        Mina, {\@author},
        \begin{enumerate}
            \item annan Tartu Ülikoolile tasuta loa (lihtlitsentsi) enda loodud teose
            \begin{center}
                \textbf{\@title},
            \end{center}
            \iftwosupervisors
                mille juhendajad on {\@firstsupervisor} ja {\@secondsupervisor},
            \else
                mille juhendaja on {\@firstsupervisor},
            \fi
            \begin{enumerate}
    	        \item reprodutseerimiseks säilitamise ja üldsusele kättesaadavaks tegemise eesmärgil, sealhulgas digitaalarhiivi DSpace-is lisamise eesmärgil kuni autoriõiguse kehtivuse täht\-aja lõppemiseni; 
    	        \item üldsusele kättesaadavaks tegemiseks Tartu Ülikooli veebikeskkonna kaudu, sealhulgas digitaalarhiivi DSpace'i kaudu kuni autoriõiguse kehtivuse tähtaja lõppemiseni.
            \end{enumerate}
            \item olen teadlik, et punktis 1 nimetatud õigused jäävad alles ka autorile.
            \item kinnitan, et lihtlitsentsi andmisega ei rikuta teiste isikute intellektuaalomandi ega isikuandmete kaitse seadusest tulenevaid õigusi.
        \end{enumerate}
        Tartu, \today
    \end{otherlanguage}
}